==> 1.0.2_20240315_release.zip: app/provider/ServiceProvider.php <==
<?php

namespace app\provider;

class ServiceProvider
{
    /**
     * 注册服务
     */
    public function register(){
        container()->bind([
            "S_Api_articleType"=>'app\service\api\S_articleType',
            "S_Api_article"=>'app\service\api\S_article',
            "S_Admin_admin"=>'app\service\admin\S_admin',
            "S_Admin_setting"=>'app\service\admin\S_setting',
            "S_Admin_articleType"=>'app\service\admin\S_articleType',
            "S_Admin_article"=>'app\service\admin\S_article',
            "S_Admin_articleData"=>'app\service\admin\S_articleData',
            "S_Admin_module"=>'app\service\admin\S_module',
            "S_Admin_map_relation"=>'app\service\admin\S_map_relation',
            "S_Admin_category"=>'app\service\admin\S_category',
            "S_Admin_categoryOp"=>'app\service\admin\S_categoryOp',
            "S_Admin_categoryChild"=>'app\service\admin\S_categoryChild',
            "S_Admin_news"=>'app\service\admin\S_news',
            "S_Admin_newsData"=>'app\service\admin\S_newsData',
            "S_Admin_flow_data"=>'app\service\admin\S_flow_data',
            "S_Admin_commendModuleData"=>'app\service\admin\S_commendModuleData',
            "S_Admin_plugin"=>'app\service\admin\S_plugin',
            "S_Admin_plugin_upgrade_log"=>'app\service\admin\S_plugin_upgrade_log',
            "S_Admin_plugin_status"=>'app\service\admin\S_plugin_status',
            "S_Admin_plugin_status_user"=>'app\service\admin\S_plugin_status_user',
            "S_Admin_op_check"=>'app\service\admin\S_op_check',
            "S_Admin_plugin_record"=>'app\service\admin\S_plugin_record',
            "S_Admin_goods"=>'app\service\admin\S_goods',
            "S_Admin_software_upgrade_log"=>'app\service\admin\S_software_upgrade_log',
        ]);

        container()->bind([
            "S_Common_row_data"=>'app\service\common\S_row_data',
        ]);

        container()->bind([
            "S_Index_adPosition"=>'app\service\index\S_adPosition',
        ]);

        //方便合并代码
        container()->bind([
            "S_Admin_adminRole"=> 'app\service\admin\S_adminRole',
            "L_Admin_adminRole"=> 'app\logic\admin\L_adminRole',
            "S_Admin_adminMenu"=> 'app\service\admin\S_adminMenu',
            "L_Admin_adminMenu"=> 'app\logic\admin\L_adminMenu',
            "L_Admin_adminFunc"=> 'app\logic\admin\L_adminFunc',
            "S_Admin_adminFunc"=> 'app\service\admin\S_adminFunc',
            "S_Admin_adminRoleFunc"=> 'app\service\admin\S_adminRoleFunc',
            "S_Admin_memberAdmin"=> 'app\service\admin\S_memberAdmin',
            "S_Admin_adPosition"=> 'app\service\admin\S_adPosition',
            "L_Admin_adPosition"=> 'app\logic\admin\L_adPosition',
            "S_Admin_adManage"=> 'app\service\admin\S_adManage',
            "S_Admin_friendLink"=> 'app\service\admin\S_friendLink',
            "S_Admin_friendLinkGroup"=> 'app\service\admin\S_friendLinkGroup',
            "S_Admin_singlePage"=> 'app\service\admin\S_singlePage',
            "L_Admin_singlePage"=> 'app\logic\admin\L_singlePage',
            "L_Admin_singlePageGroup"=> 'app\logic\admin\L_singlePageGroup',
            "S_Admin_singlePageGroup"=> 'app\service\admin\S_singlePageGroup',
            "L_Admin_exSinglePage"=> 'app\logic\admin\L_singlePage',


            //index
            "S_Index_article"=>'app\service\index\S_article',
            "L_Index_article"=>'app\logic\index\L_article',

            "S_Index_articleType"=>'app\service\index\S_articleType',
            "L_Index_articleType"=>'app\logic\index\L_articleType',

            "S_Index_friendLink"=>'app\service\index\S_friendLink',

            "S_Index_adManage"=>'app\service\index\S_adManage',

            "S_Index_singlePage"=> 'app\service\index\S_singlePage',
            "S_Index_setting"=>'app\service\index\S_setting',
            "S_Index_module"=>'app\service\index\S_module',
            "S_Index_category"=>'app\service\index\S_category',
            "S_Index_goods"=>'app\service\index\S_goods',

            "S_Api_news"=>'app\service\api\S_news',
            "S_Api_newsData"=>'app\service\api\S_newsData',
        ]);
    }

    /**
     * 服务启动
     */
    public function boot(){

    }
}

==> 1.0.20_20240718_release.zip: app/provider/ServiceProvider.php <==
<?php

namespace app\provider;

class ServiceProvider
{
    /**
     * 注册服务
     */
    public function register(){
        container()->bind([
            "S_Api_articleType"=>'app\service\api\S_articleType',
            "S_Api_article"=>'app\service\api\S_article',
            "S_Admin_admin"=>'app\service\admin\S_admin',
            "S_Admin_setting"=>'app\service\admin\S_setting',
            "S_Admin_articleType"=>'app\service\admin\S_articleType',
            "S_Admin_article"=>'app\service\admin\S_article',
            "S_Admin_articleData"=>'app\service\admin\S_articleData',
            "S_Admin_module"=>'app\service\admin\S_module',
            "S_Admin_map_relation"=>'app\service\admin\S_map_relation',
            "S_Admin_category"=>'app\service\admin\S_category',
            "S_Admin_categoryOp"=>'app\service\admin\S_categoryOp',
            "S_Admin_categoryChild"=>'app\service\admin\S_categoryChild',
            "S_Admin_news"=>'app\service\admin\S_news',
            "S_Admin_newsData"=>'app\service\admin\S_newsData',
            "S_Admin_flow_data"=>'app\service\admin\S_flow_data',
            "S_Admin_commendModuleData"=>'app\service\admin\S_commendModuleData',
            "S_Admin_plugin"=>'app\service\admin\S_plugin',
            "S_Admin_plugin_upgrade_log"=>'app\service\admin\S_plugin_upgrade_log',
            "S_Admin_plugin_status"=>'app\service\admin\S_plugin_status',
            "S_Admin_plugin_status_user"=>'app\service\admin\S_plugin_status_user',
            "S_Admin_op_check"=>'app\service\admin\S_op_check',
            "S_Admin_plugin_record"=>'app\service\admin\S_plugin_record',
            "S_Admin_goods"=>'app\service\admin\S_goods',
            "S_Admin_software_upgrade_log"=>'app\service\admin\S_software_upgrade_log',
            "S_Admin_fields"=>'app\service\admin\S_fields',
            "S_Admin_log_operation"=>'app\service\admin\S_log_operation',
        ]);

        container()->bind([
            "S_Common_row_data"=>'app\service\common\S_row_data',
        ]);

        container()->bind([
            "S_Index_adPosition"=>'app\service\index\S_adPosition',
        ]);

        //方便合并代码
        container()->bind([
            "S_Admin_adminRole"=> 'app\service\admin\S_adminRole',
            "L_Admin_adminRole"=> 'app\logic\admin\L_adminRole',
            "S_Admin_adminMenu"=> 'app\service\admin\S_adminMenu',
            "L_Admin_adminMenu"=> 'app\logic\admin\L_adminMenu',
            "L_Admin_adminFunc"=> 'app\logic\admin\L_adminFunc',
            "S_Admin_adminFunc"=> 'app\service\admin\S_adminFunc',
            "S_Admin_adminRoleFunc"=> 'app\service\admin\S_adminRoleFunc',
            "S_Admin_memberAdmin"=> 'app\service\admin\S_memberAdmin',
            "S_Admin_adPosition"=> 'app\service\admin\S_adPosition',
            "L_Admin_adPosition"=> 'app\logic\admin\L_adPosition',
            "S_Admin_adManage"=> 'app\service\admin\S_adManage',
            "S_Admin_friendLink"=> 'app\service\admin\S_friendLink',
            "S_Admin_friendLinkGroup"=> 'app\service\admin\S_friendLinkGroup',
            "S_Admin_singlePage"=> 'app\service\admin\S_singlePage',
            "L_Admin_singlePage"=> 'app\logic\admin\L_singlePage',
            "L_Admin_singlePageGroup"=> 'app\logic\admin\L_singlePageGroup',
            "S_Admin_singlePageGroup"=> 'app\service\admin\S_singlePageGroup',
            "L_Admin_exSinglePage"=> 'app\logic\admin\L_singlePage',


            //index
            "S_Index_article"=>'app\service\index\S_article',
            "L_Index_article"=>'app\logic\index\L_article',

            "S_Index_articleType"=>'app\service\index\S_articleType',
            "L_Index_articleType"=>'app\logic\index\L_articleType',

            "S_Index_friendLink"=>'app\service\index\S_friendLink',

            "S_Index_adManage"=>'app\service\index\S_adManage',

            "S_Index_singlePage"=> 'app\service\index\S_singlePage',
            "S_Index_setting"=>'app\service\index\S_setting',
            "S_Index_module"=>'app\service\index\S_module',
            "S_Index_category"=>'app\service\index\S_category',
            "S_Index_goods"=>'app\service\index\S_goods',
            "S_Index_fields"=>'app\service\index\S_fields',

            "S_Api_news"=>'app\service\api\S_news',
            "S_Api_newsData"=>'app\service\api\S_newsData',
        ]);
    }

    /**
     * 服务启动
     */
    public function boot(){

    }
}
